package org.alltimeflashdreamer.filelister;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 * <p>
 *
 * Title: AbstractFileListerServlet</p> <p>
 *
 * Description: This servlet is the superclass of each FileLister servlet and provides
 * the commonly used methods for the extending classes, such as the printing of the
 * error site(s) or the DimDom access method.</p> <p>
 *
 * Organization: All Time Flash Dreamer</p>
 *
 * @author    Copyright (c) 2002-2004 by <a href="mailto:florian@steinsiepe.ch">Florian
 *      Steinsiepe</a>
 * @version   0.5.1
 */

public abstract class AbstractFileListerServlet extends HttpServlet
{
    /** Stores the name of the config class for quick access by extending classes */
    public final static String CONFIGCLASSNAME = FileListerConfig.class.getName();

    /**
     * Redirects the client to the doPost method, so it doesn't matter whether the
     * call was through the get or the post method.
     *
     * @param request            the request object to read URL stuff from
     * @param response           the response object to send stuff to
     * @throws ServletException  as defined in the superclass
     * @throws IOException       as defined in the superclass
     */
    public void doGet( HttpServletRequest request, HttpServletResponse response )
        throws ServletException, IOException
    {
        doPost( request, response );
    }

    /**
     * (abstract declaration, to be implemented by extending classes)
     *
     * @param request            the request object to read URL stuff from
     * @param response           the response object to send stuff to
     * @throws ServletException  as defined in the superclass
     * @throws IOException       as defined in the superclass
     */
    public abstract void doPost( HttpServletRequest request, HttpServletResponse response )
        throws ServletException, IOException;

    /**
     * Initializes the appropriate procedure to show the given error to the user.
     *
     * @param fle                the FileListerException to show
     * @param response           the response to use for redirects
     * @param fileListerConfig   the magic config object
     * @throws ServletException  if the ErrorSiteProcessor itself catches an exception
     * @throws IOException       if the redirect to the error site somehow failed
     */
    public static void showErrorSite( FileListerException fle,
            HttpServletResponse response, FileListerConfig fileListerConfig )
        throws ServletException, IOException
    {
        if ( fileListerConfig != null )
        {
            fileListerConfig.setFileListerException( fle );
            //for exceptions generated by FileLister itself, the source site can only be
            //the results frame -> redirect to error site directly, else to top
            if ( fle.getRootCause() != null )
                response.sendRedirect( fileListerConfig.getErrorURL() );
            else
                response.sendRedirect( fileListerConfig.getRequestURL( false ) );
        }
        else
            throw fle;
    }
}
