package org.alltimeflashdreamer.filelister;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.alltimeflashdreamer.util.StringUtils;

/**
 * <p>
 *
 * Title: FileListerControllerServlet</p> <p>
 *
 * Description: The conroller servlet acts as the central redirection machinery.
 * It knows where the client comes from, does config stuff, if necessary, and redirects
 * the client to where he'd like to go.</p> <p>
 *
 * Organization: All Time Flash Dreamer</p> <p>
 *
 * </p>
 *
 * @author    Copyright (c) 2002-2004 by <a href="mailto:florian@steinsiepe.ch">Florian
 *      Steinsiepe</a>
 * @version   0.5.1
 */

public class FileListerControllerServlet extends AbstractFileListerServlet
{
    /**
     * This method is called from the <i>initial site only</i> . It reeads the request,
     * does some config stuff, if necessary, and redirects the client to the initial
     * site again..
     *
     * @param request            the request object to read URL stuff from
     * @param response           the response object to send stuff to
     * @throws ServletException  as defined in the superclass
     * @throws IOException       as defined in the superclass
     */
    public void doPost( HttpServletRequest request, HttpServletResponse response )
        throws ServletException, IOException
    {
        FileListerConfig fileListerConfig = FileListerFactory.getFileListerConfig( request );

        //read possible URL parameters (if sSearch is "null", set it to null)
        boolean bIsCallFromDefineSearch = ( request.getParameter( "definesearch" ) != null );
        String sSearch = request.getParameter( "search" );
        if ( sSearch != null && sSearch.equalsIgnoreCase( "null" ) )
            sSearch = null;
        String sMode = request.getParameter( "mode" );

        //Possible scenarios are:
        //- User loaded the initial site for the very first time
        //- User hasn't processed a search yet, clicked on the Simple/Advanced Search button only
        //- User clicked on a link in the option bar -> configures another search
        //- User just reloaded the site
        try
        {
            if ( fileListerConfig == null )
            {
                //very first access: initialize a default FileListerConfig instance and a
                //default DefineSearchParameters instance
                fileListerConfig = FileListerFactory.initialize( request, response, this.getServletContext() );
                fileListerConfig.createDefineSearchParameters();
            }
            else
            {
                if ( !bIsCallFromDefineSearch )
                {
                    //user clicked on a link in the optionbar.jsp: configure another search
                    fileListerConfig.setSearchType( sSearch );
                    fileListerConfig.createDefineSearchParameters();
                }
                else if ( !StringUtils.isEmpty( sMode ) )
                {
                    //notify the FileListerConfig to swith the simple/advanced mode;
                    //forces it to do everything necessary
                    fileListerConfig.processModeChange( sMode, request );
                }
            }
        } catch ( FileListerException fle )
        {
            //make sure that an upcoming exception is shown within FileLister's error site, if possible
            if ( fileListerConfig != null )
            {
                fileListerConfig.setFileListerException( fle );
                response.sendRedirect( fileListerConfig.getErrorURL() );
            }
            else
                throw fle;
        } finally
        {
            //set the back-button-in-browser switch to "legal call"
            if ( fileListerConfig != null )
                fileListerConfig.setInitialSiteWasCalledLegally();
        }

        //finally redirect to initial site
        response.sendRedirect( fileListerConfig.getInitialSiteURL() );
    }
}
