package org.alltimeflashdreamer.filelister;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * <p>
 *
 * Title: FileListerViewerServlet</p> <p>
 *
 * Description: Prepares the DimDom-ready XHTMLSiteData instance which dynamically
 * generates the output showing the appropriate number of filtered records.</p> <p>
 *
 * Organization: All Time Flash Dreamer</p>
 *
 * @author    Copyright (c) 2002-2004 by <a href="mailto:florian@steinsiepe.ch">Florian
 *      Steinsiepe</a>
 * @version   0.5.1
 */

public class FileListerViewerServlet extends AbstractFileListerServlet
{
    /**
     * Gets the config object from the client's session and generates the dynamically
     * filled XHMTLSiteData instance. After this, the configured SiteData is passed
     * to DimDom which generates the visible (X)HTML output.
     *
     * @param request            the client's request object
     * @param response           where to write the response to
     * @throws IOException       as defined in the superclass' doPost method
     */
    public void doPost( HttpServletRequest request, HttpServletResponse response )
        throws IOException
    {
        //get FileListerConfig from environment
        FileListerConfig fileListerConfig = FileListerFactory.getFileListerConfig( request );
        if ( fileListerConfig == null )
        {
            FileListerFactory.redirectToAppRoot( response );
            return;
        }

        //catch the cancelling of the download (after the click of the "Back to..." link)
        if ( fileListerConfig.getZipBuilderThread() != null )
        {
            fileListerConfig.resetZipBuilderThread();
        }

        //send the redirect to the viewer site listing the search results
        response.sendRedirect( fileListerConfig.getViewerSite() );
    }
}
