package org.alltimeflashdreamer.filelister.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Point;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.Statement;

import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.SwingConstants;

import org.alltimeflashdreamer.filelister.SQLQueryBuilder;
import org.alltimeflashdreamer.filelister.xml.ConfigElement;
import org.alltimeflashdreamer.filelister.xml.JDBC;

/**
 * <p>
 *
 * Title: FileLister</p> <p>
 *
 * Description: </p> <p>
 *
 * Organization: All Time Flash Dreamer</p> <p>
 *
 * </p>
 *
 * @author    Copyright (c) 2002-2004 by <a href="mailto:florian@steinsiepe.ch">Florian
 *      Steinsiepe</a>
 * @version   0.5.1
 */

public class ConnectionTesterDialog extends JDialog
{
    private JLabel jlTitle = new JLabel();
    private JTextArea jtTestResults = new JTextArea();
    private JCheckBox jcbTableExists = new JCheckBox();

    /**
     * Reads the settings from the given property list and tries to establish a connection.
     * If this succeeds, the defined table is queried; if this succeeds too, the
     * checkbox is set to selected.
     *
     * @param settings        where to read the settings from
     * @param parentLocation  the location of the SetupFrame
     * @param parentSize      the size of the SetupFrame
     */
    public ConnectionTesterDialog( JDBC settings, Point parentLocation,
            Dimension parentSize )
    {
        try
        {
            setSize( ( int )( parentSize.getWidth() / 1.1 ), ( int )( parentSize.getHeight() / 1.5 ) );
            setLocation( parentLocation.x + ( int )( parentSize.getWidth() / 4.4 ), parentLocation.y + ( int )( parentSize.getHeight() / 6 ) );
            jbInit();
        } catch ( Exception e )
        {
            e.printStackTrace();
        }

        try
        {
            //do description
            ConfigElement driverclassElement = settings.getConfigElement( "driverclass" );
            ConfigElement connectionstringElement = settings.getConfigElement( "connectionstring" );
            ConfigElement usernameElement = settings.getConfigElement( "username" );
            ConfigElement passwordElement = settings.getConfigElement( "password" );
            ConfigElement tablenameElement = settings.getConfigElement( "tablename" );
            jtTestResults.setText(
                    "Driver class: " + driverclassElement.getValue() + "\n" +
                    "Connection string: " + connectionstringElement.getValue() + "\n" +
                    "User name: " + usernameElement.getValue() + "\n" +
                    "Password: " + passwordElement.getValue() + "\n" +
                    "Table name: " + tablenameElement.getValue() + "\n\n" );

            //do testing
            Class.forName( ( String )driverclassElement.getValue() );
            Connection con = DriverManager.getConnection(
                    ( String )connectionstringElement.getValue(),
                    ( String )usernameElement.getValue(),
                    ( String )passwordElement.getValue() );
            Statement st = con.createStatement();
            SQLQueryBuilder queryBuilder = ( SQLQueryBuilder )
                    Class.forName( ( String )settings.getConfigElement( "querybuilderclass" ).getValue() ).newInstance();
            ResultSet rs = st.executeQuery( queryBuilder.getListAllTablesString( ( String )tablenameElement.getValue() ) );
            while ( rs.next() )
            {
                if ( rs.getString( 1 ).equals( tablenameElement.getValue() ) )
                {
                    jcbTableExists.setSelected( true );
                    break;
                }
            }
            rs.close();
            st.close();
            con.close();

            jtTestResults.setText( jtTestResults.getText() + "Connection successfully established." );
        } catch ( Exception ex )
        {
            jtTestResults.setText( jtTestResults.getText() + "Establishing of connection failed!\n\nReason is:\n" +
                    ex.getMessage() );
        }
    }

    private void jbInit()
        throws Exception
    {
        this.setBackground( SetupFrame.BGCOLOR_2 );
        this.setModal( true );
        this.setResizable( true );
        this.setTitle( "Connection Tester" );

        jlTitle.setHorizontalAlignment( SwingConstants.CENTER );
        jlTitle.setText( "Test Results:" );
        jlTitle.setBackground( SetupFrame.BGCOLOR_2 );
        jlTitle.setFont( SetupFrame.FONT_BOLD );

        jtTestResults.setText( "" );
        jtTestResults.setBackground( SetupFrame.BGCOLOR_1 );
        jtTestResults.setFont( SetupFrame.FONT_PLAIN );
        jtTestResults.setEditable( false );

        jcbTableExists.setHorizontalAlignment( SwingConstants.CENTER );
        jcbTableExists.setText( "Table exists?" );
        jcbTableExists.setBackground( SetupFrame.BGCOLOR_2 );
        jcbTableExists.setFont( SetupFrame.FONT_BOLD );
        jcbTableExists.setEnabled( false );

        this.getContentPane().add( jlTitle, BorderLayout.NORTH );
        this.getContentPane().add( new JScrollPane( jtTestResults ), BorderLayout.CENTER );
        this.getContentPane().add( jcbTableExists, BorderLayout.SOUTH );
    }
}
